@@ -1,9 +1,17 @@
 .onAttach <- function(...) {
-  # if (!interactive()) return()
 
-  packageStartupMessage("Google's Terms of Service: https://cloud.google.com/maps-platform/terms/.")
-  packageStartupMessage("Please cite ggmap if you use it! See citation(\"ggmap\") for details.")
+  cli::cli_alert_info("Google's Terms of Service: {.url https://mapsplatform.google.com}")
+  cli::cli_alert_info("Please cite {.pkg ggmap} if you use it! Use {.code citation(\"ggmap\")} for details.")
 
+  bootstrap_ggmap()
+
+}
+
+
+
+
+
+bootstrap_ggmap <- function () {
   set_ggmap_option(
     "google" = structure(
       list(
@@ -15,13 +23,10 @@
     ),
     "display_api_key" = FALSE
   )
-
 }
 
 
 
-
-
 ggmap_environment <- new.env(parent = emptyenv())
 
 
